.. dataset-creator documentation master file, created by
   sphinx-quickstart on Tue Sep 29 11:35:07 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dataset-creator's documentation!
===========================================

Contents:

.. toctree::
   :maxdepth: 2

   usage


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

